'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.args = undefined;
exports.toAbsolutePath = toAbsolutePath;
exports.log = log;
exports.showUsage = showUsage;
exports.getDate = getDate;

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _require = require('is-my-json-valid/require');

var _require2 = _interopRequireDefault(_require);

var _expandTilde = require('expand-tilde');

var _expandTilde2 = _interopRequireDefault(_expandTilde);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _toAbsoluteGlob = require('to-absolute-glob');

var _toAbsoluteGlob2 = _interopRequireDefault(_toAbsoluteGlob);

var _yargs = require('yargs');

var _lodash = require('lodash');

var _package = require('../package.json');

var _package2 = _interopRequireDefault(_package);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// -----------------------------------------------------------------------------

var FOLDER = process.cwd();
var isConfigValid = (0, _require2.default)('../schema.json');

var configOpt = _yargs.argv.config || _yargs.argv.c || _yargs.argv._[0]; // argv._[0]: first unnamed arg
var destinationOpt = _yargs.argv.destination || _yargs.argv.dest || _yargs.argv.d;
var logOpt = _yargs.argv.log || _yargs.argv.l;
var help = _yargs.argv.help || _yargs.argv.h;

var args = exports.args = {
  configPath: configOpt && toAbsolutePath(configOpt),
  destinationPath: destinationOpt && toAbsolutePath(destinationOpt) || FOLDER,
  logPath: logOpt && toAbsolutePath(logOpt)
};

if (help) {
  showUsage();
  process.exit(0);
}

var config = void 0;
try {
  config = require(args.configPath);
} catch (e) {
  console.log('Config file not found');
  process.exit(1);
}
module.exports.config = config; // TODO: ES6

if (!isConfigValid(config)) {
  console.log('Invalid config:');
  (0, _lodash.forEach)(isConfigValid.errors, function (error) {
    console.log(`\t${error.field} ${error.message}`);
  });
  process.exit(1);
}

// -----------------------------------------------------------------------------

function toAbsolutePath() {
  var relativePath = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

  return (0, _toAbsoluteGlob2.default)((0, _expandTilde2.default)(relativePath), { cwd: FOLDER });
}

function log(message) {
  var time = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
  var logPath = args.logPath;


  if (time) {
    message = `[${getDate()}] ${message}`;
  }

  if (logPath) {
    _fs2.default.appendFile(logPath, `${message}\n`, function (e) {
      if (e) {
        console.error(e);
      }
    });
  } else {
    console.log(message);
  }
}

function showUsage() {
  console.log(_chalk2.default.yellow.underline('Usage:') + _chalk2.default.yellow('\n\n$ file-fetcher <config file> [-d <destination folder>] [-l <log file>]') + _chalk2.default.yellow(`\n\n${_package2.default.name} ${_package2.default.version}`));
}

function getDate() {
  return (0, _moment2.default)().format('YYYY-MM-DD ss:mm:hh');
}
//# sourceMappingURL=utils.js.map